summaryrefslogtreecommitdiffstats
path: root/src/include/gpxe/ftp.h
diff options
context:
space:
mode:
authorMichael Brown2007-01-31 03:09:13 +0100
committerMichael Brown2007-01-31 03:09:13 +0100
commit6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de (patch)
tree9ba9ac5ba0a755bdb6f10a563b22dac61ef4045d /src/include/gpxe/ftp.h
parentFirst sketch of stream API (diff)
downloadipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.tar.gz
ipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.tar.xz
ipxe-6d32f0e6e2179afa4e78ab94d3fbfb691a6f99de.zip
Changed to use the generic stream API.
Diffstat (limited to 'src/include/gpxe/ftp.h')
-rw-r--r--src/include/gpxe/ftp.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/include/gpxe/ftp.h b/src/include/gpxe/ftp.h
index 64e8d4e4f..41eca8ca4 100644
--- a/src/include/gpxe/ftp.h
+++ b/src/include/gpxe/ftp.h
@@ -9,7 +9,7 @@
#include <stdint.h>
#include <gpxe/async.h>
-#include <gpxe/tcp.h>
+#include <gpxe/stream.h>
struct buffer;
@@ -57,10 +57,10 @@ struct ftp_request {
char status_text[4];
/** Passive-mode parameters, as text */
char passive_text[24]; /* "aaa,bbb,ccc,ddd,eee,fff" */
- /** TCP application for the control channel */
- struct tcp_application tcp;
- /** TCP application for the data channel */
- struct tcp_application tcp_data;
+ /** Stream application for the control channel */
+ struct stream_application stream;
+ /** Stream application for the data channel */
+ struct stream_application stream_data;
};
extern int ftp_get ( struct uri *uri, struct buffer *buffer,